<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="76"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddLabelDialog</name>
    <message>
        <location filename="add_label_dialog.cpp" line="8"/>
        <source>Label name:</source>
        <translation>Название ярлыка:</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="11"/>
        <source>Choose a color:</source>
        <translation>Выбрать цвет:</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="14"/>
        <source>red</source>
        <translation>красный</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="15"/>
        <source>orange</source>
        <translation>оранжевый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="16"/>
        <source>yellow</source>
        <translation>желтый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="17"/>
        <source>green</source>
        <translation>зеленый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="18"/>
        <source>cyan</source>
        <translation>голубой</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="19"/>
        <source>blue</source>
        <translation>синий</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="20"/>
        <source>violet</source>
        <translation>фиолетовый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="21"/>
        <source>purple</source>
        <translation>пурпурный</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="22"/>
        <source>pink</source>
        <translation>розовый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="23"/>
        <source>white</source>
        <translation>белый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="24"/>
        <source>light</source>
        <translation>серый</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="25"/>
        <source>dark</source>
        <translation>темный</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="36"/>
        <source>accept</source>
        <translation>добавить</translation>
    </message>
    <message>
        <location filename="add_label_dialog.cpp" line="37"/>
        <source>cancel</source>
        <translation>отменить</translation>
    </message>
</context>
<context>
    <name>AddLibraryDialog</name>
    <message>
        <location filename="add_library_dialog.cpp" line="17"/>
        <source>Comics folder : </source>
        <translation>Папка комиксов : </translation>
    </message>
    <message>
        <location filename="add_library_dialog.cpp" line="22"/>
        <source>Library name : </source>
        <oldsource>Library Name : </oldsource>
        <translation>Имя библиотеки : </translation>
    </message>
    <message>
        <location filename="add_library_dialog.cpp" line="27"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="add_library_dialog.cpp" line="31"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="add_library_dialog.cpp" line="67"/>
        <source>Add an existing library</source>
        <translation>Добавить в существующую библиотеку</translation>
    </message>
</context>
<context>
    <name>ApiKeyDialog</name>
    <message>
        <location filename="comic_vine/api_key_dialog.cpp" line="21"/>
        <source>Before you can connect to Comic Vine, you need your own API key. Please, get one free &lt;a href=&quot;http://www.comicvine.com/api/&quot;&gt;here&lt;/a&gt;</source>
        <translation>Для подключения к Comic Vine вам потребуется ваш личный API ключ. Приобретите его бесплатно вот &lt;a href=&quot;http://www.comicvine.com/api/&quot;&gt;здесь&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="comic_vine/api_key_dialog.cpp" line="25"/>
        <source>Paste here your Comic Vine API key</source>
        <translation>Вставьте сюда ваш Comic Vine API ключ</translation>
    </message>
    <message>
        <location filename="comic_vine/api_key_dialog.cpp" line="28"/>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="comic_vine/api_key_dialog.cpp" line="32"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ClassicComicsView</name>
    <message>
        <location filename="classic_comics_view.cpp" line="92"/>
        <source>Hide comic flow</source>
        <translation>Показать/скрыть поток комиксов</translation>
    </message>
</context>
<context>
    <name>ComicInfoView</name>
    <message>
        <location filename="qml/ComicInfoView.qml" line="275"/>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="305"/>
        <source>writer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="327"/>
        <source>penciller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="349"/>
        <source>inker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="371"/>
        <source>colorist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="393"/>
        <source>letterer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="415"/>
        <source>cover artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="430"/>
        <source>Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="470"/>
        <source>color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="470"/>
        <source>b/w</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qml/ComicInfoView.qml" line="498"/>
        <source>Characters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComicModel</name>
    <message>
        <location filename="db/comic_model.cpp" line="316"/>
        <source>yes</source>
        <translation>да</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="316"/>
        <source>no</source>
        <translation>нет</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="345"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="347"/>
        <source>File Name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="349"/>
        <source>Pages</source>
        <translation>Всего страниц</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="351"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="353"/>
        <source>Read</source>
        <translation>Прочитано</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="355"/>
        <source>Current Page</source>
        <translation>Текущая страница</translation>
    </message>
    <message>
        <location filename="db/comic_model.cpp" line="357"/>
        <source>Rating</source>
        <translation>Рейтинг</translation>
    </message>
</context>
<context>
    <name>ComicVineDialog</name>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="55"/>
        <source>skip</source>
        <translation>пропустить</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="56"/>
        <source>back</source>
        <translation>назад</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="57"/>
        <source>next</source>
        <translation>дальше</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="58"/>
        <source>search</source>
        <translation>искать</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="59"/>
        <source>close</source>
        <translation>закрыть</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="133"/>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="145"/>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="243"/>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="692"/>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="726"/>
        <source>Looking for volume...</source>
        <translation>Поиск информации...</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="143"/>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="659"/>
        <source>comic %1 of %2 - %3</source>
        <translation>комикс %1 of %2 - %3</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="249"/>
        <source>%1 comics selected</source>
        <translation>%1 было выбрано</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="284"/>
        <source>Error connecting to ComicVine</source>
        <translation>Ошибка поключения к ComicVine</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="447"/>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="485"/>
        <source>Retrieving tags for : %1</source>
        <translation>Получение тегов для : %1</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="707"/>
        <source>Retrieving volume info...</source>
        <translation>Получение информации...</translation>
    </message>
    <message>
        <location filename="comic_vine/comic_vine_dialog.cpp" line="733"/>
        <source>Looking for comic...</source>
        <translation>Поиск комикса...</translation>
    </message>
</context>
<context>
    <name>CreateLibraryDialog</name>
    <message>
        <location filename="create_library_dialog.cpp" line="17"/>
        <source>Comics folder : </source>
        <translation>Папка комиксов : </translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="22"/>
        <source>Library Name : </source>
        <translation>Имя библиотеки:</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="27"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="31"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="53"/>
        <source>Create a library could take several minutes. You can stop the process and update the library later for completing the task.</source>
        <translation>Создание библиотеки может занять несколько минут. Вы можете остановить процесс и обновить библиотеку позже для завершения задачи.</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="75"/>
        <source>Create new library</source>
        <translation>Создать новую библиотеку</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="99"/>
        <source>Path not found</source>
        <translation>Путь не найден</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="99"/>
        <source>The selected path does not exist or is not a valid path. Be sure that you have write access to this folder</source>
        <translation>Выбранный путь отсутствует, либо неверен. Убедитесь , что у вас есть доступ к этой папке</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="21"/>
        <source>Restore defaults</source>
        <translation>Вернуть к первоначальным значениям</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="22"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation>Чтобы изменить горячую клавишу щелкните дважды по выбранной комбинации клавиш и введите новые сочетания клавиш.</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="70"/>
        <source>Shortcuts settings</source>
        <translation>Горячие клавиши</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation>Горячая клавиша уже занята</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation>Сочетание клавиш &quot;%1&quot; уже назначено для другой функции</translation>
    </message>
</context>
<context>
    <name>EmptyFolderWidget</name>
    <message>
        <location filename="empty_folder_widget.cpp" line="67"/>
        <location filename="empty_folder_widget.cpp" line="139"/>
        <source>Subfolders in this folder</source>
        <translation>Подпапки в этой папке</translation>
    </message>
    <message>
        <location filename="empty_folder_widget.cpp" line="135"/>
        <source>Empty folder</source>
        <translation>Пустая папка</translation>
    </message>
    <message>
        <location filename="empty_folder_widget.cpp" line="135"/>
        <source>Drag and drop folders and comics here</source>
        <translation>Перетащите папки и комиксы сюда</translation>
    </message>
</context>
<context>
    <name>EmptyLabelWidget</name>
    <message>
        <location filename="empty_label_widget.cpp" line="11"/>
        <source>This label doesn&apos;t contain comics yet</source>
        <translation>Этот ярлык пока ничего не содержит</translation>
    </message>
</context>
<context>
    <name>EmptyReadingListWidget</name>
    <message>
        <location filename="empty_reading_list_widget.cpp" line="8"/>
        <source>This reading list does not contain any comics yet</source>
        <oldsource>This reading list doesn&apos;t contain comics yet</oldsource>
        <translation>Этот список чтения пока ничего не содержит</translation>
    </message>
</context>
<context>
    <name>ExportComicsInfoDialog</name>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="14"/>
        <source>Output file : </source>
        <translation>Путь сохранения : </translation>
    </message>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="18"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="22"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="57"/>
        <source>Export comics info</source>
        <translation>Экспортировать информацию комикса</translation>
    </message>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="67"/>
        <source>Destination database name</source>
        <translation>Имя этой базы данных</translation>
    </message>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="85"/>
        <source>Problem found while writing</source>
        <translation>Обнаружена Ошибка записи</translation>
    </message>
    <message>
        <location filename="export_comics_info_dialog.cpp" line="85"/>
        <source>The selected path for the output file does not exist or is not a valid path. Be sure that you have write access to this folder</source>
        <translation>Выбранный путь для импортируемого файла отсутствует, либо неверен. Убедитесь , что у вас есть доступ к этой папке</translation>
    </message>
</context>
<context>
    <name>ExportLibraryDialog</name>
    <message>
        <location filename="export_library_dialog.cpp" line="11"/>
        <source>Output folder : </source>
        <translation>Папка вывода : </translation>
    </message>
    <message>
        <location filename="export_library_dialog.cpp" line="15"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="export_library_dialog.cpp" line="19"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="export_library_dialog.cpp" line="60"/>
        <source>Create covers package</source>
        <translation>Создать комплект обложек</translation>
    </message>
    <message>
        <location filename="export_library_dialog.cpp" line="73"/>
        <source>Problem found while writing</source>
        <translation>Проблема при написании</translation>
    </message>
    <message>
        <location filename="export_library_dialog.cpp" line="73"/>
        <source>The selected path for the output file does not exist or is not a valid path. Be sure that you have write access to this folder</source>
        <translation>Выбранный путь для импортируемого файла отсутствует, либо неверен. Убедитесь , что у вас есть доступ к этой папке</translation>
    </message>
    <message>
        <location filename="export_library_dialog.cpp" line="79"/>
        <source>Destination directory</source>
        <translation>Назначенная директория</translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="437"/>
        <source>Unknown error opening the file</source>
        <translation>Неизвестная ошибка при открытии файла</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="563"/>
        <source>7z not found</source>
        <translation>7z не найден</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="570"/>
        <source>Format not supported</source>
        <translation>Формат не поддерживается</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="430"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation>Ошибка контрольной суммы CRC на странице (%1): некоторые страницы будут отображаться неправильно</translation>
    </message>
</context>
<context>
    <name>GridComicsView</name>
    <message>
        <location filename="grid_comics_view.cpp" line="177"/>
        <source>Show info</source>
        <translation>Показать информацию</translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="21"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="24"/>
        <source>Help</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>ImportComicsInfoDialog</name>
    <message>
        <location filename="import_comics_info_dialog.cpp" line="14"/>
        <source>Import comics info</source>
        <translation>Импортировать информацию комикса</translation>
    </message>
    <message>
        <location filename="import_comics_info_dialog.cpp" line="17"/>
        <source>Info database location : </source>
        <translation>Путь к файлу : </translation>
    </message>
    <message>
        <location filename="import_comics_info_dialog.cpp" line="21"/>
        <source>Import</source>
        <translation>Импортировать</translation>
    </message>
    <message>
        <location filename="import_comics_info_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="import_comics_info_dialog.cpp" line="77"/>
        <source>Comics info file (*.ydb)</source>
        <translation>Инфо файл комикса (*.ydb)</translation>
    </message>
</context>
<context>
    <name>ImportLibraryDialog</name>
    <message>
        <location filename="import_library_dialog.cpp" line="17"/>
        <source>Library Name : </source>
        <translation>Имя библиотеки : </translation>
    </message>
    <message>
        <location filename="import_library_dialog.cpp" line="22"/>
        <source>Package location : </source>
        <translation>Местоположение комплекта : </translation>
    </message>
    <message>
        <location filename="import_library_dialog.cpp" line="26"/>
        <source>Destination folder : </source>
        <translation>Папка назначения : </translation>
    </message>
    <message>
        <location filename="import_library_dialog.cpp" line="30"/>
        <source>Unpack</source>
        <translation>Распаковать</translation>
    </message>
    <message>
        <location filename="import_library_dialog.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="import_library_dialog.cpp" line="87"/>
        <source>Extract a catalog</source>
        <translation>Извлечь каталог</translation>
    </message>
    <message>
        <location filename="import_library_dialog.cpp" line="111"/>
        <source>Compresed library covers (*.clc)</source>
        <translation>Сжатая библиотека обложек (*.clc)</translation>
    </message>
</context>
<context>
    <name>ImportWidget</name>
    <message>
        <location filename="import_widget.cpp" line="346"/>
        <source>Importing comics</source>
        <translation>Импорт комиксов</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="154"/>
        <source>stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="194"/>
        <source>Some of the comics being added...</source>
        <translation>Поиск новых комиксов...</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="347"/>
        <source>&lt;p&gt;YACReaderLibrary is now creating a new library.&lt;/p&gt;&lt;p&gt;Create a library could take several minutes. You can stop the process and update the library later for completing the task.&lt;/p&gt;</source>
        <oldsource>Create a library could take several minutes. You can stop the process and update the library later for completing the task.</oldsource>
        <translation>&lt;p&gt;YACReaderLibrary сейчас создает библиотеку.&lt;/p&gt;&lt;p&gt; Создание библиотеки может занять несколько минут. Вы можете остановить процесс и обновить библиотеку позже для завершения задачи.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="358"/>
        <source>Updating the library</source>
        <translation>Обновление библиотеки</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="359"/>
        <source>&lt;p&gt;The current library is being updated. For faster updates, please, update your libraries frequently.&lt;/p&gt;&lt;p&gt;You can stop the process and continue updating this library later.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;The current library is being updated. For faster updates, please, update your libraries frequently.&lt;/p&gt;&lt;p&gt;You can stop the process and continue updating this library later.</oldsource>
        <translation>&lt;p&gt;Для сокращения времени этого процесса периодически обновляйте вашу библиотеку после добавления новых комиксов.
Вы можете остановить этот процесс и продолжить обновление этой библиотеки позже.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="370"/>
        <source>Upgrading the library</source>
        <translation>Обновление библиотеки</translation>
    </message>
    <message>
        <location filename="import_widget.cpp" line="371"/>
        <source>&lt;p&gt;The current library is being upgraded, please wait.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Библиотека обновляется, пожалуйста подождите.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>LibraryWindow</name>
    <message>
        <location filename="library_window.cpp" line="132"/>
        <source>YACReader Library</source>
        <translation>Библиотека YACReader</translation>
    </message>
    <message>
        <source>&lt;font color=&apos;white&apos;&gt; press &apos;F&apos; to close fullscreen mode &lt;/font&gt;</source>
        <translation type="vanished">&lt;font color=&apos;white&apos;&gt; нажмите &apos;F&apos; чтобы выйте из Полноэкранного режима &lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="450"/>
        <source>Create a new library</source>
        <translation>Создать новую библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="456"/>
        <source>Open an existing library</source>
        <translation>Открыть существующую библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="461"/>
        <location filename="library_window.cpp" line="462"/>
        <source>Export comics info</source>
        <translation>Экспортировать данные комиксов</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="467"/>
        <location filename="library_window.cpp" line="468"/>
        <source>Import comics info</source>
        <translation>Импортировать данные комиксов</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="473"/>
        <source>Pack covers</source>
        <translation>Запаковать обложки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="474"/>
        <source>Pack the covers of the selected library</source>
        <translation>Запаковать обложки выбранной библиотеки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="479"/>
        <source>Unpack covers</source>
        <translation>Распаковать обложки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="480"/>
        <source>Unpack a catalog</source>
        <translation>Распаковать каталог</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="485"/>
        <source>Update library</source>
        <translation>Обновить библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="486"/>
        <source>Update current library</source>
        <translation>Обновить эту библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="491"/>
        <source>Rename library</source>
        <translation>Переименовать библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="492"/>
        <source>Rename current library</source>
        <translation>Переименовать эту библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="498"/>
        <source>Remove current library from your collection</source>
        <translation>Удалить эту библиотеку из своей коллекции</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="503"/>
        <source>Open current comic</source>
        <translation>Открыть выбранный комикс</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="504"/>
        <source>Open current comic on YACReader</source>
        <translation>Открыть комикс в YACReader</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="509"/>
        <source>Save selected covers to...</source>
        <translation>Сохранить выбранные обложки в...</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="510"/>
        <source>Save covers of the selected comics as JPG files</source>
        <translation>Сохранить обложки выбранных комиксов как JPG файлы</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="514"/>
        <location filename="library_window.cpp" line="637"/>
        <source>Set as read</source>
        <translation>Отметить как прочитано</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="515"/>
        <source>Set comic as read</source>
        <translation>Отметить комикс как прочитано</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="520"/>
        <location filename="library_window.cpp" line="642"/>
        <source>Set as unread</source>
        <translation>Отметить как не прочитано</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="521"/>
        <source>Set comic as unread</source>
        <translation>Отметить комикс как не прочитано</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="534"/>
        <source>Show/Hide marks</source>
        <translation>Показать/Спрятать пометки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="542"/>
        <location filename="library_window.cpp" line="543"/>
        <source>Fullscreen mode on/off</source>
        <translation>Полноэкранный режим включить/выключить</translation>
    </message>
    <message>
        <source>Fullscreen mode on/off (F)</source>
        <translation type="vanished">полноекранный режим включить/выключить(F)</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="551"/>
        <source>Help, About YACReader</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="573"/>
        <source>Select root node</source>
        <translation>Домашняя папка</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="577"/>
        <source>Expand all nodes</source>
        <translation>Раскрыть все папки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="589"/>
        <source>Show options dialog</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="597"/>
        <source>Show comics server options dialog</source>
        <translation>Настройки сервера YACReader</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="621"/>
        <source>Open folder...</source>
        <translation>Открыть папку...</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="627"/>
        <source>Set as uncompleted</source>
        <translation>Отметить как не завершено</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="632"/>
        <source>Set as completed</source>
        <translation>Отметить как завершено</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="647"/>
        <source>Open containing folder...</source>
        <translation>Открыть выбранную папку...</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="653"/>
        <source>Reset comic rating</source>
        <translation>Сбросить рейтинг комикса</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="659"/>
        <source>Select all comics</source>
        <translation>Выбрать все комиксы</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="665"/>
        <source>Edit</source>
        <translation>Редактировать информацию</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="677"/>
        <source>Update cover</source>
        <translation>Обновить обложки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="683"/>
        <source>Delete selected comics</source>
        <translation>Удалить выбранное</translation>
    </message>
    <message>
        <source>Hide comic flow</source>
        <translation type="vanished">Не показывать поток комиксов</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="691"/>
        <source>Download tags from Comic Vine</source>
        <translation>Скачать теги из Comic Vine</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="952"/>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="963"/>
        <source>Comic</source>
        <translation>Комикс</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1255"/>
        <source>Library not available</source>
        <oldsource>Library &apos;</oldsource>
        <translation>Библиотека не доступна</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1255"/>
        <source>Library &apos;%1&apos; is no longer available. Do you want to remove it?</source>
        <translation>Библиотека &apos;%1&apos; больше не доступна. Вы хотите удалить ее?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1279"/>
        <source>Library &apos;%1&apos; has been created with an older version of YACReaderLibrary. It must be created again. Do you want to create the library now?</source>
        <translation>Библиотека &apos;%1&apos; была создана старой версией YACReaderLibrary. Она должна быть вновь создана. Вы хотите создать библиотеку сейчас?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1279"/>
        <source>Old library</source>
        <translation>Библиотека из старой версии YACreader</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1836"/>
        <location filename="library_window.cpp" line="1838"/>
        <source>YACReader not found</source>
        <translation>YACReader не найден</translation>
    </message>
    <message>
        <source>YACReader not found, YACReader should be installed in the same folder as YACReaderLibrary.</source>
        <translation type="vanished">YACReader не найден, YACReader должен быть установлен в ту же папку что и YACReaderLibrary.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1551"/>
        <location filename="library_window.cpp" line="2243"/>
        <source>Unable to delete</source>
        <translation>Не удалось удалить</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2243"/>
        <source>There was an issue trying to delete the selected comics. Please, check for write permissions in the selected files or containing folder.</source>
        <translation>Возникла проблема при удалении выбранных комиксов. Пожалуйста, проверьте права на запись для выбранных файлов или содержащую их папку.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2276"/>
        <source>Assign comics numbers</source>
        <translation>Порядковый номер</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2277"/>
        <source>Assign numbers starting in:</source>
        <translation>Назначить порядковый номер начиная с:</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2455"/>
        <source>Error creating the library</source>
        <translation>Ошибка создания библиотеки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2460"/>
        <source>Error updating the library</source>
        <translation>Ошибка обновления библиотеки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2465"/>
        <source>Error opening the library</source>
        <translation>Ошибка открытия библиотеки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2503"/>
        <source>Delete comics</source>
        <translation>Удалить комиксы</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2503"/>
        <source>All the selected comics will be deleted from your disk. Are you sure?</source>
        <translation>Все выбранные комиксы будут удалены с вашего жёсткого диска. Вы уверены?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2550"/>
        <source>Remove comics</source>
        <translation>Убрать комиксы</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2550"/>
        <source>Comics will only be deleted from the current label/list. Are you sure?</source>
        <translation>Комиксы будут удалены только из выбранного списка/ярлыка. Вы уверены?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2620"/>
        <source>Library name already exists</source>
        <translation>Имя папки уже используется</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="2620"/>
        <source>There is another library with the name &apos;%1&apos;.</source>
        <translation>Уже существует другая папка с именем &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="936"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="497"/>
        <source>Remove library</source>
        <translation>Удалить библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="535"/>
        <source>Show or hide read marks</source>
        <translation>Показать или спрятать отметку прочтено</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="558"/>
        <location filename="library_window.cpp" line="1476"/>
        <source>Add new folder</source>
        <translation>Добавить новую папку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="561"/>
        <source>Add new folder to the current library</source>
        <translation>Добавить новую папку в текущую библиотеку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="564"/>
        <location filename="library_window.cpp" line="1516"/>
        <source>Delete folder</source>
        <translation>Удалить папку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="567"/>
        <source>Delete current folder from disk</source>
        <translation>Удалить выбранную папку с жёсткого диска</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="583"/>
        <source>Collapse all nodes</source>
        <translation>Свернуть все папки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="604"/>
        <location filename="library_window.cpp" line="605"/>
        <source>Change between comics views</source>
        <translatorcomment>Может нужно поменять на другое выражение.</translatorcomment>
        <translation>Изменение внешнего вида потока комиксов</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="671"/>
        <source>Assign current order to comics</source>
        <translation>Назначить порядковый номер</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="695"/>
        <source>Edit shortcuts</source>
        <translation>Редактировать горячие клавиши</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="701"/>
        <source>Update folder</source>
        <translation>Обновить папку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="704"/>
        <source>Update current folder</source>
        <translation>Обновить выбранную папку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="709"/>
        <source>Add new reading list</source>
        <translation>Создать новый список чтения</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="712"/>
        <source>Add a new reading list to the current library</source>
        <translation>Создать новый список чтения</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="715"/>
        <source>Remove reading list</source>
        <translation>Удалить список чтения</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="718"/>
        <source>Remove current reading list from the library</source>
        <translation>Удалить выбранный ярлык/список чтения</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="721"/>
        <source>Add new label</source>
        <translation>Создать новый ярлык</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="724"/>
        <source>Add a new label to this library</source>
        <translation>Создать новый ярлык</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="727"/>
        <source>Rename selected list</source>
        <translation>Переименовать выбранный список</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="730"/>
        <source>Rename any selected labels or lists</source>
        <translation>Переименовать выбранный ярлык/список чтения</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="734"/>
        <source>Add to...</source>
        <translation>Добавить в...</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="736"/>
        <source>Favorites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="739"/>
        <source>Add selected comics to favorites list</source>
        <translation>Добавить выбранные комиксы в список избранного</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1140"/>
        <source>Upgrade failed</source>
        <translation>Обновить не удалось</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1140"/>
        <source>There were errors during library upgrade in: </source>
        <translation>При обновлении библиотеки произошли ошибки: </translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1159"/>
        <source>Update needed</source>
        <translation>Необходимо обновление</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1159"/>
        <source>This library was created with a previous version of YACReaderLibrary. It needs to be updated. Update now?</source>
        <translation>Эта библиотека была создана в предыдущей версии YACReaderLibrary. Требуется обновление. Обновить сейчас?</translation>
    </message>
    <message>
        <source>Update failed</source>
        <translation type="vanished">Обновить не удалось</translation>
    </message>
    <message>
        <source>The current library can&apos;t be udpated. Check for write write permissions on: </source>
        <translation type="vanished">В настоящее время библиотека не может быть обновлена. Проверьте права на чтение/запись: </translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1231"/>
        <source>Download new version</source>
        <translation>Загрузить новую версию</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1231"/>
        <source>This library was created with a newer version of YACReaderLibrary. Download the new version now?</source>
        <translation>Эта библиотека была создана новой версией YACReaderLibrary. Скачать новую версию сейчас?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1315"/>
        <location filename="library_window.cpp" line="1353"/>
        <source>Copying comics...</source>
        <translation>Скопировать комиксы...</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1333"/>
        <location filename="library_window.cpp" line="1373"/>
        <source>Moving comics...</source>
        <translation>Переместить комиксы...</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1477"/>
        <source>Folder name:</source>
        <translation>Имя папки:</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1508"/>
        <source>No folder selected</source>
        <translation>Ни одна папка не была выбрана</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1508"/>
        <source>Please, select a folder first</source>
        <translation>Пожалуйста, сначала выберите папку</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1513"/>
        <source>Error in path</source>
        <translation>Ошибка в пути</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1513"/>
        <source>There was an error accessing the folder&apos;s path</source>
        <translation>Ошибка доступа к пути папки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1516"/>
        <source>The selected folder and all its contents will be deleted from your disk. Are you sure?</source>
        <translation>Выбранная папка и все ее содержимое будет удалено с вашего жёсткого диска. Вы уверены?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1551"/>
        <source>There was an issue trying to delete the selected folders. Please, check for write permissions and be sure that any applications are using these folders or any of the contained files.</source>
        <translation>Возникла проблема при удалении выбранных папок. Пожалуйста, проверьте права на запись и убедитесь что другие приложения не используют эти папки или файлы.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1564"/>
        <source>Add new reading lists</source>
        <translation>Добавить новый список чтения</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1565"/>
        <location filename="library_window.cpp" line="1621"/>
        <source>List name:</source>
        <translation>Имя списка:</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1586"/>
        <source>Delete list/label</source>
        <translation>Удалить список/ярлык</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1586"/>
        <source>The selected item will be deleted, your comics or folders will NOT be deleted from your disk. Are you sure?</source>
        <translation>Выбранные элементы будут удалены, ваши комиксы или папки НЕ БУДУТ удалены с вашего жёсткого диска. Вы уверены?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1620"/>
        <source>Rename list name</source>
        <translation>Изменить имя списка</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1746"/>
        <source>Save covers</source>
        <translation>Сохранить обложки</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1767"/>
        <source>You are adding too many libraries.</source>
        <translation>Вы добавляете слишком много библиотек.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1767"/>
        <source>You are adding too many libraries.

You probably only need one library in your top level comics folder, you can browse any subfolders using the folders section in the left sidebar.

YACReaderLibrary will not stop you from creating more libraries but you should keep the number of libraries low.</source>
        <translation>Вы добавляете слишком много библиотек.

Вероятно, вам нужна только одна библиотека в папке комиксов верхнего уровня, вы можете просматривать любые подпапки, используя раздел папок на левой боковой панели.

YACReaderLibrary не помешает вам создать больше библиотек, но вы должны иметь не большое количество библиотек.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1836"/>
        <source>YACReader not found. YACReader should be installed in the same folder as YACReaderLibrary.</source>
        <translation>YACReader не найден, YACReader должен быть установлен в ту же папку что и YACReaderLibrary.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1838"/>
        <source>YACReader not found. There might be a problem with your YACReader installation.</source>
        <translation>YACReader не найден. Возможно, повреждены системные файлы YACReader. Переустановите YACReader.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1925"/>
        <source>Library not found</source>
        <translation>Библиотека не найдена</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1925"/>
        <source>The selected folder doesn&apos;t contain any library.</source>
        <translation>Выбранная папка не содержит ни одной библиотеки.</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1982"/>
        <source>Are you sure?</source>
        <translation>Вы уверены?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1982"/>
        <source> library?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1983"/>
        <source>Remove and delete metadata</source>
        <translation>Удаление метаданных</translation>
    </message>
    <message>
        <location filename="library_window.cpp" line="1982"/>
        <source>Do you want remove </source>
        <translation>Вы хотите удалить библиотеку </translation>
    </message>
    <message>
        <source>Asign comics numbers</source>
        <translation type="vanished">Назначение номеров комикса</translation>
    </message>
    <message>
        <source>Asign numbers starting in:</source>
        <translation type="vanished">Назначьте номера, начинающиеся на:</translation>
    </message>
</context>
<context>
    <name>LocalComicListModel</name>
    <message>
        <location filename="comic_vine/model/local_comic_list_model.cpp" line="76"/>
        <source>file name</source>
        <translation>имя файла</translation>
    </message>
</context>
<context>
    <name>NoLibrariesWidget</name>
    <message>
        <location filename="no_libraries_widget.cpp" line="26"/>
        <source>You don&apos;t have any libraries yet</source>
        <translation>У вас нет ни одной библиотеки</translation>
    </message>
    <message>
        <location filename="no_libraries_widget.cpp" line="28"/>
        <source>&lt;p&gt;You can create a library in any folder, YACReaderLibrary will import all comics and folders from this folder. If you have created any library in the past you can open them.&lt;/p&gt;&lt;p&gt;Don&apos;t forget that you can use YACReader as a stand alone application for reading the comics on your computer.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Вы можете создать библиотеку в любой папке, YACReaderLibrary будет импортировать все комиксы и папки из этой папки. Если вы уже ранее создавали библиотеки, их можно будет открыть.&lt; / p &gt; &lt;p&gt;Не забывайте, что Вы можете использовать YACReader в качестве отдельного приложения для чтения комиксов на вашем компьютере.&lt;/п&gt;</translation>
    </message>
    <message>
        <location filename="no_libraries_widget.cpp" line="32"/>
        <source>create your first library</source>
        <translation>создайте свою первую библиотеку</translation>
    </message>
    <message>
        <location filename="no_libraries_widget.cpp" line="34"/>
        <source>add an existing one</source>
        <translation>добавить уже существующую</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="46"/>
        <source>Edit Comic Vine API key</source>
        <translation>Редактировать Comic Vine API ключ</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="49"/>
        <source>Comic Vine API key</source>
        <translation>Comic Vine API ключ</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="55"/>
        <source>Enable background image</source>
        <translation>Включить фоновое изображение</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="57"/>
        <source>Opacity level</source>
        <translation>Уровень непрозрачности</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="62"/>
        <source>Blur level</source>
        <translation>Уровень размытия</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="67"/>
        <source>Use selected comic cover as background</source>
        <translation>Обложка комикса фоновое изображение</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="69"/>
        <source>Restore defautls</source>
        <translation>Вернуть к первоначальным значениям</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="80"/>
        <source>Background</source>
        <translation>Фоновое изображение</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="105"/>
        <source>Comic Flow</source>
        <translation>Поток комиксов</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="107"/>
        <source>Grid view</source>
        <translation>Фоновое изображение</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="109"/>
        <source>General</source>
        <translation>Основные</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="117"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="properties_dialog.cpp" line="74"/>
        <source>General info</source>
        <translation>Общая информация</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="75"/>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="76"/>
        <source>Publishing</source>
        <translation>Издатели</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="77"/>
        <source>Plot</source>
        <translation>Сюжет</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="86"/>
        <source>Cover page</source>
        <translation>Страница обложки</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="147"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="156"/>
        <location filename="properties_dialog.cpp" line="173"/>
        <source>of:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="163"/>
        <source>Issue number:</source>
        <translation>Номер выпуска</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="165"/>
        <source>Volume:</source>
        <translation>Объём :</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="169"/>
        <source>Arc number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="178"/>
        <source>Story arc:</source>
        <translation>Сюжетная арка:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="180"/>
        <source>Genre:</source>
        <oldsource>Genere:</oldsource>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="182"/>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="206"/>
        <source>Writer(s):</source>
        <translation>Писатель(и):</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="209"/>
        <source>Penciller(s):</source>
        <translation>Художник(и):</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="217"/>
        <source>Inker(s):</source>
        <translation>Контуровщик(и):</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="220"/>
        <source>Colorist(s):</source>
        <translation>Колорист(ы):</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="230"/>
        <source>Letterer(s):</source>
        <translation>Гравёр-шрифтовик(и):</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="233"/>
        <source>Cover Artist(s):</source>
        <translation>Художник(и) Обложки:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="256"/>
        <source>Day:</source>
        <translation>День:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="260"/>
        <source>Month:</source>
        <translation>Месяц:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="264"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="272"/>
        <source>Publisher:</source>
        <translation>Издатель:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="273"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="274"/>
        <source>Color/BW:</source>
        <translation>Цвет/BW:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="275"/>
        <source>Age rating:</source>
        <translation>Возрастной рейтинг:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="288"/>
        <source>Synopsis:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="289"/>
        <source>Characters:</source>
        <translation>Персонажи:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="290"/>
        <source>Notes:</source>
        <translation>Заметки:</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="388"/>
        <source>Comic Vine link: &lt;a style=&apos;color: #FFCB00; text-decoration:none; font-weight:bold;&apos; href=&quot;http://www.comicvine.com/comic/4000-%1/&quot;&gt; view &lt;/a&gt;</source>
        <translation>&lt;a style=&apos;color: ##666666; text-decoration:none; font-weight:bold;&apos; href=&quot;http://www.comicvine.com/comic/4000-%1/&quot;&gt; Открыть страницу этого комикса на сайте Comic Vine &lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="416"/>
        <source>Not found</source>
        <translation>Не найдено</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="416"/>
        <source>Comic not found. You should update your library.</source>
        <translation>Комикс не найден. Обновите вашу библиотеку.</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="491"/>
        <source>Edit selected comics information</source>
        <translation>Редактировать информацию выбранного комикса</translation>
    </message>
    <message>
        <location filename="properties_dialog.cpp" line="562"/>
        <source>Edit comic information</source>
        <translation>Редактировать информацию комикса</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="14"/>
        <source>7z lib not found</source>
        <translation>Библиотека распаковщика 7z не найдена</translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="14"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation>Не удается загрузить библиотеку распаковщика 7z из ./utils</translation>
    </message>
</context>
<context>
    <name>RenameLibraryDialog</name>
    <message>
        <location filename="rename_library_dialog.cpp" line="17"/>
        <source>New Library Name : </source>
        <translation>Новое имя библиотеки:</translation>
    </message>
    <message>
        <location filename="rename_library_dialog.cpp" line="22"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="rename_library_dialog.cpp" line="26"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="rename_library_dialog.cpp" line="54"/>
        <source>Rename current library</source>
        <translation>Переименовать эту библиотеку</translation>
    </message>
</context>
<context>
    <name>ScraperResultsPaginator</name>
    <message>
        <location filename="comic_vine/scraper_results_paginator.cpp" line="32"/>
        <source>Number of volumes found : %1</source>
        <translation>Количество найденных томов : %1</translation>
    </message>
    <message>
        <location filename="comic_vine/scraper_results_paginator.cpp" line="34"/>
        <location filename="comic_vine/scraper_results_paginator.cpp" line="57"/>
        <source>page %1 of %2</source>
        <translation>страница %1 из %2</translation>
    </message>
    <message>
        <location filename="comic_vine/scraper_results_paginator.cpp" line="56"/>
        <source>Number of %1 found : %2</source>
        <translation>Количество из %1 найдено : %2</translation>
    </message>
</context>
<context>
    <name>SearchSingleComic</name>
    <message>
        <location filename="comic_vine/search_single_comic.cpp" line="14"/>
        <source>Please provide some additional information.</source>
        <translation>Пожалуйста, введите инфомарцию для поиска.</translation>
    </message>
    <message>
        <location filename="comic_vine/search_single_comic.cpp" line="19"/>
        <source>Series:</source>
        <translation>Серия:</translation>
    </message>
</context>
<context>
    <name>SearchVolume</name>
    <message>
        <location filename="comic_vine/search_volume.cpp" line="11"/>
        <source>Please provide some additional information.</source>
        <translation>Пожалуйста, введите инфомарцию для поиска.</translation>
    </message>
    <message>
        <location filename="comic_vine/search_volume.cpp" line="14"/>
        <source>Series:</source>
        <translation>Серия:</translation>
    </message>
</context>
<context>
    <name>SelectComic</name>
    <message>
        <location filename="comic_vine/select_comic.cpp" line="17"/>
        <source>Please, select the right comic info.</source>
        <translation>Пожалуйста, выберите правильную информацию об комиксе.</translation>
    </message>
    <message>
        <location filename="comic_vine/select_comic.cpp" line="37"/>
        <source>comics</source>
        <translation>комиксы</translation>
    </message>
    <message>
        <location filename="comic_vine/select_comic.cpp" line="93"/>
        <source>loading cover</source>
        <translation>загрузка обложки</translation>
    </message>
    <message>
        <location filename="comic_vine/select_comic.cpp" line="94"/>
        <source>loading description</source>
        <translation>загрузка описания</translation>
    </message>
    <message>
        <location filename="comic_vine/select_comic.cpp" line="137"/>
        <source>description unavailable</source>
        <translation>описание недоступно</translation>
    </message>
</context>
<context>
    <name>SelectVolume</name>
    <message>
        <location filename="comic_vine/select_volume.cpp" line="32"/>
        <source>Please, select the right series for your comic.</source>
        <translation>Пожалуйста, выберите правильную серию для вашего комикса.</translation>
    </message>
    <message>
        <location filename="comic_vine/select_volume.cpp" line="60"/>
        <source>volumes</source>
        <translation>тома</translation>
    </message>
    <message>
        <location filename="comic_vine/select_volume.cpp" line="122"/>
        <source>loading cover</source>
        <translation>загрузка обложки</translation>
    </message>
    <message>
        <location filename="comic_vine/select_volume.cpp" line="123"/>
        <source>loading description</source>
        <translation>загрузка описания</translation>
    </message>
    <message>
        <location filename="comic_vine/select_volume.cpp" line="166"/>
        <source>description unavailable</source>
        <translation>описание недоступно</translation>
    </message>
</context>
<context>
    <name>SeriesQuestion</name>
    <message>
        <location filename="comic_vine/series_question.cpp" line="13"/>
        <source>You are trying to get information for various comics at once, are they part of the same series?</source>
        <translation>Вы пытаетесь получить информацию для нескольких комиксов одновременно, являются ли они все частью одной серии?</translation>
    </message>
    <message>
        <location filename="comic_vine/series_question.cpp" line="15"/>
        <source>yes</source>
        <translation>да</translation>
    </message>
    <message>
        <location filename="comic_vine/series_question.cpp" line="16"/>
        <source>no</source>
        <translation>нет</translation>
    </message>
</context>
<context>
    <name>ServerConfigDialog</name>
    <message>
        <location filename="server_config_dialog.cpp" line="85"/>
        <source>set port</source>
        <translation>указать порт</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="91"/>
        <source>Server connectivity information</source>
        <translation>Информация о подключении</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="95"/>
        <source>Scan it!</source>
        <translation>Сканируйте!</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="101"/>
        <source>YACReader is available for iOS devices. &lt;a href=&apos;http://ios.yacreader.com&apos; style=&apos;color:rgb(193, 148, 65)&apos;&gt; Discover it! &lt;/a&gt;</source>
        <translation>&lt;a href=&apos;http://ios.yacreader.com&apos; style=&apos;color:rgb(102,102,102)&apos;&gt;YACReader доступен для устройств с iOS.&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="110"/>
        <source>Choose an IP address</source>
        <translation>Выбрать IP адрес</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="114"/>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="147"/>
        <source>enable the server</source>
        <translation>активировать сервер</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="152"/>
        <source>display less information about folders in the browser
to improve the performance</source>
        <translation>отображать меньше информации о папках в браузере
для улучшения производительности</translation>
    </message>
    <message>
        <location filename="server_config_dialog.cpp" line="287"/>
        <source>Could not load libqrencode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>QR generator error!</source>
        <translation type="vanished">Ошибка QR генератора!</translation>
    </message>
</context>
<context>
    <name>SortVolumeComics</name>
    <message>
        <location filename="comic_vine/sort_volume_comics.cpp" line="18"/>
        <source>Please, sort the list of comics on the left until it matches the comics&apos; information.</source>
        <translation>Пожалуйста, отсортируйте список комиксов слева, пока он не будет соответствовать информации комикса.</translation>
    </message>
    <message>
        <location filename="comic_vine/sort_volume_comics.cpp" line="21"/>
        <source>sort comics to match comic information</source>
        <translation>сортировать комиксы, чтобы соответствовать информации комиксов</translation>
    </message>
    <message>
        <location filename="comic_vine/sort_volume_comics.cpp" line="58"/>
        <source>issues</source>
        <translation>выпуск</translation>
    </message>
    <message>
        <location filename="comic_vine/sort_volume_comics.cpp" line="87"/>
        <source>remove selected comics</source>
        <translation>удалить выбранные комиксы</translation>
    </message>
    <message>
        <location filename="comic_vine/sort_volume_comics.cpp" line="88"/>
        <source>restore all removed comics</source>
        <translation>восстановить все удаленные комиксы</translation>
    </message>
    <message>
        <source>restore removed comics</source>
        <translation type="vanished">восстановить удаленные комиксы</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Title</source>
        <translation type="vanished">Заголовок</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="vanished">Имя файла</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation type="vanished">Страницы</translation>
    </message>
</context>
<context>
    <name>TitleHeader</name>
    <message>
        <location filename="comic_vine/title_header.cpp" line="30"/>
        <source>SEARCH</source>
        <translation>ПОИСК</translation>
    </message>
</context>
<context>
    <name>UpdateLibraryDialog</name>
    <message>
        <location filename="create_library_dialog.cpp" line="166"/>
        <source>Updating....</source>
        <translation>Обновление...</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="172"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="create_library_dialog.cpp" line="191"/>
        <source>Update library</source>
        <translation>Обновить библиотеку</translation>
    </message>
</context>
<context>
    <name>VolumeComicsModel</name>
    <message>
        <location filename="comic_vine/model/volume_comics_model.cpp" line="130"/>
        <source>title</source>
        <translation>название</translation>
    </message>
</context>
<context>
    <name>VolumesModel</name>
    <message>
        <location filename="comic_vine/model/volumes_model.cpp" line="129"/>
        <source>year</source>
        <translation>год</translation>
    </message>
    <message>
        <location filename="comic_vine/model/volumes_model.cpp" line="131"/>
        <source>issues</source>
        <translation>выпуск</translation>
    </message>
    <message>
        <location filename="comic_vine/model/volumes_model.cpp" line="133"/>
        <source>publisher</source>
        <translation>издатель</translation>
    </message>
</context>
<context>
    <name>YACReaderDeletingProgress</name>
    <message>
        <location filename="../custom_widgets/yacreader_deleting_progress.cpp" line="20"/>
        <source>Please wait, deleting in progress...</source>
        <translation>Пожалуйста подождите, удаление в процессе...</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_deleting_progress.cpp" line="35"/>
        <source>cancel</source>
        <translation>отменить</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="29"/>
        <source>Click to overwrite</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>Вернуть к первоначальным значениям</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="20"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="45"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="51"/>
        <source>Click to overwrite</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>Вернуть к первоначальным значениям</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>Выбрать внешний вид потока обложек:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>Рулеткой</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>Вид полосами</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>Вид перекрывающимися полосами</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="19"/>
        <source>Presets:</source>
        <translation>Предустановки:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="21"/>
        <source>Classic look</source>
        <translation>Классический вид</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="24"/>
        <source>Stripe look</source>
        <translation>Вид полосами</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="27"/>
        <source>Overlapped Stripe look</source>
        <translation>Вид перекрывающимися полосами</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="30"/>
        <source>Modern look</source>
        <translation>Современный вид</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="33"/>
        <source>Roulette look</source>
        <translation>Вид рулеткой</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="77"/>
        <source>Show advanced settings</source>
        <translation>Показать дополнительные настройки</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="86"/>
        <source>Custom:</source>
        <translation>Пользовательский:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="89"/>
        <source>View angle</source>
        <translation>Угол зрения</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="95"/>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="101"/>
        <source>Cover gap</source>
        <translation>Охватить разрыв</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="107"/>
        <source>Central gap</source>
        <translation>Сфокусировать разрыв</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="113"/>
        <source>Zoom</source>
        <translation>Масштабировать</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="119"/>
        <source>Y offset</source>
        <translation>Смещение по Y</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="125"/>
        <source>Z offset</source>
        <translation>Смещение по Z</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="131"/>
        <source>Cover Angle</source>
        <translation>Охватить угол</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="137"/>
        <source>Visibility</source>
        <translation>Прозрачность</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="143"/>
        <source>Light</source>
        <translation>Осветить</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="149"/>
        <source>Max angle</source>
        <translation>Максимальный угол</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="181"/>
        <source>Low Performance</source>
        <translation>Минимальная производительность</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="183"/>
        <source>High Performance</source>
        <translation>Максимальная производительность</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="194"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>Использовать VSync (повысить качество изображения в полноэкранном режиме , хуже производительность)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="202"/>
        <source>Performance:</source>
        <translation>Производительность:</translation>
    </message>
</context>
<context>
    <name>YACReaderNavigationController</name>
    <message>
        <location filename="yacreader_navigation_controller.cpp" line="134"/>
        <source>No favorites</source>
        <translation>Нет избранного</translation>
    </message>
    <message>
        <location filename="yacreader_navigation_controller.cpp" line="138"/>
        <source>You are not reading anything yet, come on!!</source>
        <translation>Вы пока ничего не читаете. Может самое время почитать?</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="35"/>
        <source>Edit shortcuts</source>
        <translation>Редактировать горячие клавиши</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="38"/>
        <source>Shortcuts</source>
        <translation>Горячие клавиши</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="47"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>Использовать аппаратное ускорение (необходима перезагрузка)</translation>
    </message>
</context>
<context>
    <name>YACReaderSearchLineEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_search_line_edit.cpp" line="48"/>
        <source>type to search</source>
        <translation>Начать поиск</translation>
    </message>
</context>
<context>
    <name>YACReaderSideBar</name>
    <message>
        <location filename="../custom_widgets/yacreader_sidebar.cpp" line="27"/>
        <source>Libraries</source>
        <translation>Библиотеки</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_sidebar.cpp" line="28"/>
        <source>Folders</source>
        <translation>Папки</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_sidebar.cpp" line="29"/>
        <source>Reading Lists</source>
        <translation>Списки чтения</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_sidebar.cpp" line="31"/>
        <source>LIBRARIES</source>
        <translation>БИБЛИОТЕКИ</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_sidebar.cpp" line="32"/>
        <source>FOLDERS</source>
        <translation>ПАПКИ</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_sidebar.cpp" line="33"/>
        <source>READING LISTS</source>
        <translation>СПИСКИ ЧТЕНИЯ</translation>
    </message>
</context>
</TS>
